/*
	System: Structured text retrieval tool sgrep.
	Module: sysdeps.h
	Author: Pekka Kilpelinen & Jani Jaakkola
	Description: header file for system dependent stuff.
	Version history: Original version February 1998 by JJ
	Copyright: University of Helsinki, Dept. of Computer Science
		   Distributed under GNU General Public Lisence
		   See file COPYING for details
*/

#ifdef HAVE_CONFIG_H
# define HAVE_UNIX 1
#elif WIN32
# define HAVE_WIN32 1
#else
# error "No config.h provided for target and not a WIN32 system.\n Did you forger 'configure'?"
#endif

#if HAVE_WIN32
# include <io.h>
# define read _read
# define open _open
/* MSVC4.1 io.h lacks R_OK */
# define R_OK 4
#endif

/*
 * Cygwin32 requires O_BINARY flag to open()
 * In other systems it can safely be ignored
 */
#ifndef O_BINARY
#define O_BINARY 0
#endif

/* 
 * Default macro files
 */
#if HAVE_WIN32
# define USER_SGREPRC "sgreprc"
# define SYSTEM_SGREPRC "\\etc\\sgreprc"
#else
# define USER_SGREPRC	".sgreprc" 
# define SYSTEM_SGREPRC	LIBDIR"/sgreprc"
#endif

/* 
 * Define this if you wan't sgrep to be able to exec external preprocessors 
 */
#define USE_EXEC

/*
 * Default preprocessor. "-" means none.
 */
#define PRE_PROCESSOR "m4"

/* #define UNIX_PREPROCESS  */


/*
 * If you want stream mode by default define this
 */
/* #define STREAM_MODE */

/*
 * Default temp file directories
 */
#ifndef DEFAULT_TEMP_DIR
# if HAVE_WIN32
#  define DEFAULT_TEMP_DIR ""
# else
#  define DEFAULT_TEMP_DIR "/tmp"
# endif
#endif /* ifndef DEFAULT_TEMP_DIR */

/* 
 * Sgrep has some very heavy assertion which slow sgrep down considerably.
 * However, since this is a development version of sgrep, i suggest that
 * you keep assertions on */
/* #define NDEBUG */



